/* app-window.c generated by valac 0.38.4, the Vala compiler
 * generated from app-window.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>
#include <gdk/gdk.h>
#include <libcommon.h>
#include <atk/atk.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_WIZARD_WINDOW (boxes_wizard_window_get_type ())
#define BOXES_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindow))
#define BOXES_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))
#define BOXES_IS_WIZARD_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_IS_WIZARD_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_WINDOW))
#define BOXES_WIZARD_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_WINDOW, BoxesWizardWindowClass))

typedef struct _BoxesWizardWindow BoxesWizardWindow;
typedef struct _BoxesWizardWindowClass BoxesWizardWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_ICON_VIEW (boxes_icon_view_get_type ())
#define BOXES_ICON_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICON_VIEW, BoxesIconView))
#define BOXES_ICON_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ICON_VIEW, BoxesIconViewClass))
#define BOXES_IS_ICON_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICON_VIEW))
#define BOXES_IS_ICON_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ICON_VIEW))
#define BOXES_ICON_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ICON_VIEW, BoxesIconViewClass))

typedef struct _BoxesIconView BoxesIconView;
typedef struct _BoxesIconViewClass BoxesIconViewClass;

#define BOXES_TYPE_LIST_VIEW (boxes_list_view_get_type ())
#define BOXES_LIST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIST_VIEW, BoxesListView))
#define BOXES_LIST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIST_VIEW, BoxesListViewClass))
#define BOXES_IS_LIST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIST_VIEW))
#define BOXES_IS_LIST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIST_VIEW))
#define BOXES_LIST_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIST_VIEW, BoxesListViewClass))

typedef struct _BoxesListView BoxesListView;
typedef struct _BoxesListViewClass BoxesListViewClass;

#define BOXES_APP_WINDOW_TYPE_VIEW_TYPE (boxes_app_window_view_type_get_type ())

#define BOXES_TYPE_ICOLLECTION_VIEW (boxes_icollection_view_get_type ())
#define BOXES_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionView))
#define BOXES_IS_ICOLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICOLLECTION_VIEW))
#define BOXES_ICOLLECTION_VIEW_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_ICOLLECTION_VIEW, BoxesICollectionViewIface))

typedef struct _BoxesICollectionView BoxesICollectionView;
typedef struct _BoxesICollectionViewIface BoxesICollectionViewIface;

#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
enum  {
	BOXES_APP_WINDOW_0_PROPERTY,
	BOXES_APP_WINDOW_PREVIOUS_UI_STATE_PROPERTY,
	BOXES_APP_WINDOW_UI_STATE_PROPERTY,
	BOXES_APP_WINDOW_CURRENT_ITEM_PROPERTY,
	BOXES_APP_WINDOW_FULLSCREENED_PROPERTY,
	BOXES_APP_WINDOW_SELECTION_MODE_PROPERTY,
	BOXES_APP_WINDOW_NOTIFICATIONBAR_PROPERTY,
	BOXES_APP_WINDOW_VIEW_TYPE_PROPERTY,
	BOXES_APP_WINDOW_VIEW_PROPERTY,
	BOXES_APP_WINDOW_NUM_PROPERTIES
};
static GParamSpec* boxes_app_window_properties[BOXES_APP_WINDOW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

#define BOXES_TYPE_KBD_SHORTCUTS_WINDOW (boxes_kbd_shortcuts_window_get_type ())
#define BOXES_KBD_SHORTCUTS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_KBD_SHORTCUTS_WINDOW, BoxesKbdShortcutsWindow))
#define BOXES_KBD_SHORTCUTS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_KBD_SHORTCUTS_WINDOW, BoxesKbdShortcutsWindowClass))
#define BOXES_IS_KBD_SHORTCUTS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_KBD_SHORTCUTS_WINDOW))
#define BOXES_IS_KBD_SHORTCUTS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_KBD_SHORTCUTS_WINDOW))
#define BOXES_KBD_SHORTCUTS_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_KBD_SHORTCUTS_WINDOW, BoxesKbdShortcutsWindowClass))

typedef struct _BoxesKbdShortcutsWindow BoxesKbdShortcutsWindow;
typedef struct _BoxesKbdShortcutsWindowClass BoxesKbdShortcutsWindowClass;
typedef struct _BoxesNotificationbarPrivate BoxesNotificationbarPrivate;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_NOTIFICATION (boxes_notification_get_type ())
#define BOXES_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotification))
#define BOXES_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))
#define BOXES_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATION))
#define BOXES_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATION))
#define BOXES_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))

typedef struct _BoxesNotification BoxesNotification;
typedef struct _BoxesNotificationClass BoxesNotificationClass;
typedef struct _Block9Data Block9Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _BoxesWizardWindowPrivate BoxesWizardWindowPrivate;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;
typedef struct _BoxesPropertiesWindowPrivate BoxesPropertiesWindowPrivate;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_TROUBLESHOOT_LOG (boxes_troubleshoot_log_get_type ())
#define BOXES_TROUBLESHOOT_LOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLog))
#define BOXES_TROUBLESHOOT_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLogClass))
#define BOXES_IS_TROUBLESHOOT_LOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TROUBLESHOOT_LOG))
#define BOXES_IS_TROUBLESHOOT_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TROUBLESHOOT_LOG))
#define BOXES_TROUBLESHOOT_LOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLogClass))

typedef struct _BoxesTroubleshootLog BoxesTroubleshootLog;
typedef struct _BoxesTroubleshootLogClass BoxesTroubleshootLogClass;

#define BOXES_TYPE_PROPERTIES_TOOLBAR (boxes_properties_toolbar_get_type ())
#define BOXES_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar))
#define BOXES_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))
#define BOXES_IS_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_IS_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_PROPERTIES_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))

typedef struct _BoxesPropertiesToolbar BoxesPropertiesToolbar;
typedef struct _BoxesPropertiesToolbarClass BoxesPropertiesToolbarClass;
enum  {
	BOXES_APP_WINDOW_ITEM_SELECTED_SIGNAL,
	BOXES_APP_WINDOW_NUM_SIGNALS
};
static guint boxes_app_window_signals[BOXES_APP_WINDOW_NUM_SIGNALS] = {0};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesWizardWindow* wizard_window;
	BoxesPropertiesWindow* props_window;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesSelectionbar* selectionbar;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef enum  {
	BOXES_APP_WINDOW_VIEW_TYPE_ICON = 1,
	BOXES_APP_WINDOW_VIEW_TYPE_LIST = 2
} BoxesAppWindowViewType;

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

struct _BoxesICollectionViewIface {
	GTypeInterface parent_iface;
	GList* (*get_selected_items) (BoxesICollectionView* self);
	void (*activate_first_item) (BoxesICollectionView* self);
	void (*select_by_criteria) (BoxesICollectionView* self, BoxesSelectionCriteria criteria);
	BoxesCollectionFilter* (*get_filter) (BoxesICollectionView* self);
	void (*set_filter) (BoxesICollectionView* self, BoxesCollectionFilter* value);
};

struct _BoxesAppWindowPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	BoxesCollectionItem* _current_item;
	GBinding* status_bind;
	gulong got_error_id;
	gulong machine_state_notify_id;
	gulong machine_deleted_notify_id;
	gboolean _selection_mode;
	BoxesIconView* icon_view;
	BoxesListView* list_view;
	BoxesAppWindowViewType _view_type;
	BoxesICollectionView** views;
	gint views_length1;
	gint _views_size_;
	BoxesNotificationbar* _notificationbar;
	guint configure_id;
	GtkWindowGroup* group;
};

struct _BoxesNotificationbar {
	GtkGrid parent_instance;
	BoxesNotificationbarPrivate * priv;
	BoxesSearchbar* searchbar;
};

struct _BoxesNotificationbarClass {
	GtkGridClass parent_class;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
	BoxesAsyncLauncher* async_launcher;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _Block9Data {
	int _ref_count_;
	BoxesAppWindow* self;
	gchar* text;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesWizardWindow {
	GtkWindow parent_instance;
	BoxesWizardWindowPrivate * priv;
	GtkStack* view;
	BoxesWizard* wizard;
	GtkGrid* customization_grid;
	GtkFileChooserWidget* file_chooser;
	BoxesWizardToolbar* topbar;
	BoxesNotificationbar* notificationbar;
};

struct _BoxesWizardWindowClass {
	GtkWindowClass parent_class;
};

struct _BoxesPropertiesWindow {
	GtkWindow parent_instance;
	BoxesPropertiesWindowPrivate * priv;
	GtkStack* view;
	BoxesProperties* properties;
	BoxesTroubleshootLog* troubleshoot_log;
	GtkFileChooserWidget* file_chooser;
	BoxesPropertiesToolbar* topbar;
	BoxesNotificationbar* notificationbar;
};

struct _BoxesPropertiesWindowClass {
	GtkWindowClass parent_class;
};


static gpointer boxes_app_window_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesUIIface * boxes_app_window_boxes_ui_parent_iface = NULL;

GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_wizard_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_icon_view_get_type (void) G_GNUC_CONST;
GType boxes_list_view_get_type (void) G_GNUC_CONST;
GType boxes_app_window_view_type_get_type (void) G_GNUC_CONST;
GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_icollection_view_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
#define BOXES_APP_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_APP_WINDOW, BoxesAppWindowPrivate))
#define BOXES_APP_WINDOW_TRANSITION_DURATION ((guint) 400)
#define BOXES_APP_WINDOW_configure_id_timeout ((guint) 100)
BoxesAppWindow* boxes_app_window_new (GtkApplication* app);
BoxesAppWindow* boxes_app_window_construct (GType object_type, GtkApplication* app);
static void boxes_app_window_ui_state_changed (BoxesAppWindow* self);
static void _boxes_app_window_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GtkCssProvider* boxes_load_css (const gchar* css);
static gint _variant_get1 (GVariant* value);
static gint _variant_get2 (GVariant* value);
static gint _variant_get3 (GVariant* value);
static gint _variant_get4 (GVariant* value);
static void __lambda246_ (BoxesAppWindow* self);
GType boxes_kbd_shortcuts_window_get_type (void) G_GNUC_CONST;
BoxesKbdShortcutsWindow* boxes_kbd_shortcuts_window_new (void);
BoxesKbdShortcutsWindow* boxes_kbd_shortcuts_window_construct (GType object_type);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void ___lambda246__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
void boxes_app_window_setup_ui (BoxesAppWindow* self);
void boxes_topbar_setup_ui (BoxesTopbar* self, BoxesAppWindow* window);
void boxes_display_page_setup_ui (BoxesDisplayPage* self, BoxesAppWindow* window);
void boxes_icon_view_setup_ui (BoxesIconView* self, BoxesAppWindow* window);
void boxes_list_view_setup_ui (BoxesListView* self, BoxesAppWindow* window);
void boxes_selectionbar_setup_ui (BoxesSelectionbar* self, BoxesAppWindow* window);
void boxes_searchbar_setup_ui (BoxesSearchbar* self, BoxesAppWindow* window);
void boxes_empty_boxes_setup_ui (BoxesEmptyBoxes* self, BoxesAppWindow* window);
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
BoxesWizardWindow* boxes_wizard_window_new (BoxesAppWindow* app_window);
BoxesWizardWindow* boxes_wizard_window_construct (GType object_type, BoxesAppWindow* app_window);
BoxesPropertiesWindow* boxes_properties_window_new (BoxesAppWindow* app_window);
BoxesPropertiesWindow* boxes_properties_window_construct (GType object_type, BoxesAppWindow* app_window);
static void boxes_app_window_save_window_geometry (BoxesAppWindow* self);
static gboolean boxes_app_window_get_maximized (BoxesAppWindow* self);
static GVariant* _variant_new5 (gint* value, gint value_length1);
static GVariant* _variant_new6 (gint* value, gint value_length1);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
GType boxes_machine_get_type (void) G_GNUC_CONST;
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
guint boxes_collection_get_length (BoxesCollection* self);
BoxesICollectionView* boxes_app_window_get_view (BoxesAppWindow* self);
void boxes_app_window_set_fullscreened (BoxesAppWindow* self, gboolean value);
void boxes_app_window_foreach_view (BoxesAppWindow* self, GFunc func, void* func_target);
static void ___lambda223_ (BoxesAppWindow* self, BoxesICollectionView* view);
static void ____lambda223__gfunc (gconstpointer data, gpointer self);
void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value);
GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self);
void boxes_machine_schedule_autosave (BoxesMachine* self);
void boxes_machine_unschedule_autosave (BoxesMachine* self);
const gchar* boxes_ui_state_to_string (BoxesUIState self);
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
void boxes_app_window_show_properties (BoxesAppWindow* self);
gboolean boxes_app_window_get_selection_mode (BoxesAppWindow* self);
void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value);
GList* boxes_icollection_view_get_selected_items (BoxesICollectionView* self);
void boxes_app_window_set_current_item (BoxesAppWindow* self, BoxesCollectionItem* value);
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
void boxes_app_window_connect_to (BoxesAppWindow* self, BoxesMachine* machine);
void boxes_machine_set_window (BoxesMachine* self, BoxesAppWindow* value);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
static void __lambda55_ (BoxesAppWindow* self, const gchar* message);
GType boxes_notification_get_type (void) G_GNUC_CONST;
BoxesNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void ___lambda55__boxes_machine_got_error (BoxesMachine* _sender, const gchar* message, gpointer self);
void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item);
BoxesAppWindow* boxes_app_get_main_window (BoxesApp* self);
void boxes_app_window_filter (BoxesAppWindow* self, const gchar* text);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static void __lambda13_ (Block9Data* _data9_, BoxesICollectionView* view);
BoxesCollectionFilter* boxes_icollection_view_get_filter (BoxesICollectionView* self);
void boxes_collection_filter_set_text (BoxesCollectionFilter* self, const gchar* value);
static void ___lambda13__gfunc (gconstpointer data, gpointer self);
gboolean boxes_app_window_on_key_pressed (BoxesAppWindow* self, GtkWidget* widget, GdkEventKey* event);
gboolean boxes_app_window_get_fullscreened (BoxesAppWindow* self);
gboolean boxes_app_quit_app (BoxesApp* self);
void boxes_topbar_click_new_button (BoxesTopbar* self);
void boxes_topbar_click_search_button (BoxesTopbar* self);
void boxes_topbar_click_back_button (BoxesTopbar* self);
void boxes_topbar_click_cancel_button (BoxesTopbar* self);
static gboolean _boxes_app_window_on_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static gboolean boxes_app_window_on_configure_event (BoxesAppWindow* self);
static gboolean __lambda247_ (BoxesAppWindow* self);
static gboolean ___lambda247__gsource_func (gpointer self);
static gboolean _boxes_app_window_on_configure_event_gtk_widget_configure_event (GtkWidget* _sender, GdkEventConfigure* event, gpointer self);
static gboolean boxes_app_window_on_window_state_event (BoxesAppWindow* self, GdkEventWindowState* event);
static gboolean _boxes_app_window_on_window_state_event_gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self);
static gboolean boxes_app_window_on_delete_event (BoxesAppWindow* self);
gboolean boxes_app_remove_window (BoxesApp* self, BoxesAppWindow* window);
static gboolean _boxes_app_window_on_delete_event_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
static void boxes_app_window_on_machine_state_notify (BoxesAppWindow* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static void boxes_app_window_on_machine_deleted_notify (BoxesAppWindow* self);
gboolean boxes_machine_get_deleted (BoxesMachine* self);
static void _boxes_app_window_on_machine_state_notify_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_app_window_on_machine_deleted_notify_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_troubleshoot_log_get_type (void) G_GNUC_CONST;
GType boxes_properties_toolbar_get_type (void) G_GNUC_CONST;
BoxesAppWindowViewType boxes_app_window_get_view_type (BoxesAppWindow* self);
void boxes_app_window_set_view_type (BoxesAppWindow* self, BoxesAppWindowViewType value);
static void boxes_app_window_finalize (GObject * obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_app_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_app_window_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


GType boxes_app_window_view_type_get_type (void) {
	static volatile gsize boxes_app_window_view_type_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_app_window_view_type_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_APP_WINDOW_VIEW_TYPE_ICON, "BOXES_APP_WINDOW_VIEW_TYPE_ICON", "icon"}, {BOXES_APP_WINDOW_VIEW_TYPE_LIST, "BOXES_APP_WINDOW_VIEW_TYPE_LIST", "list"}, {0, NULL, NULL}};
		GType boxes_app_window_view_type_type_id;
		boxes_app_window_view_type_type_id = g_enum_register_static ("BoxesAppWindowViewType", values);
		g_once_init_leave (&boxes_app_window_view_type_type_id__volatile, boxes_app_window_view_type_type_id);
	}
	return boxes_app_window_view_type_type_id__volatile;
}


static void _boxes_app_window_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 136 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_ui_state_changed ((BoxesAppWindow*) self);
#line 598 "app-window.c"
}


static gint _variant_get1 (GVariant* value) {
#line 149 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return g_variant_get_int32 (value);
#line 605 "app-window.c"
}


static gint _variant_get2 (GVariant* value) {
#line 150 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return g_variant_get_int32 (value);
#line 612 "app-window.c"
}


static gint _variant_get3 (GVariant* value) {
#line 160 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return g_variant_get_int32 (value);
#line 619 "app-window.c"
}


static gint _variant_get4 (GVariant* value) {
#line 161 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return g_variant_get_int32 (value);
#line 626 "app-window.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return self ? g_object_ref (self) : NULL;
#line 633 "app-window.c"
}


static void __lambda246_ (BoxesAppWindow* self) {
	BoxesKbdShortcutsWindow* window = NULL;
	BoxesKbdShortcutsWindow* _tmp0_;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
	BoxesKbdShortcutsWindow* _tmp13_;
#line 170 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_kbd_shortcuts_window_new ();
#line 170 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_ref_sink (_tmp0_);
#line 170 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	window = _tmp0_;
#line 171 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 171 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = _tmp1_;
#line 171 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp2_ == BOXES_UI_STATE_COLLECTION) {
#line 655 "app-window.c"
		BoxesKbdShortcutsWindow* _tmp3_;
#line 172 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp3_ = window;
#line 172 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_object_set ((GtkShortcutsWindow*) _tmp3_, "view-name", "overview", NULL);
#line 661 "app-window.c"
	} else {
		gboolean _tmp4_ = FALSE;
		BoxesUIState _tmp5_;
		BoxesUIState _tmp6_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 173 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp6_ = _tmp5_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		if (_tmp6_ == BOXES_UI_STATE_WIZARD) {
#line 173 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp4_ = TRUE;
#line 674 "app-window.c"
		} else {
			BoxesUIState _tmp7_;
			BoxesUIState _tmp8_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp7_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 173 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp8_ = _tmp7_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp4_ = _tmp8_ == BOXES_UI_STATE_PROPERTIES;
#line 684 "app-window.c"
		}
#line 173 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		if (_tmp4_) {
#line 688 "app-window.c"
			BoxesKbdShortcutsWindow* _tmp9_;
#line 174 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp9_ = window;
#line 174 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			g_object_set ((GtkShortcutsWindow*) _tmp9_, "view-name", "wizard", NULL);
#line 694 "app-window.c"
		} else {
			BoxesUIState _tmp10_;
			BoxesUIState _tmp11_;
#line 175 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp10_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 175 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp11_ = _tmp10_;
#line 175 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			if (_tmp11_ == BOXES_UI_STATE_DISPLAY) {
#line 704 "app-window.c"
				BoxesKbdShortcutsWindow* _tmp12_;
#line 176 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp12_ = window;
#line 176 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				g_object_set ((GtkShortcutsWindow*) _tmp12_, "view-name", "display", NULL);
#line 710 "app-window.c"
			}
		}
	}
#line 178 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp13_ = window;
#line 178 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_show ((GtkWidget*) _tmp13_);
#line 169 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (window);
#line 720 "app-window.c"
}


static void ___lambda246__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 169 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	__lambda246_ ((BoxesAppWindow*) self);
#line 727 "app-window.c"
}


BoxesAppWindow* boxes_app_window_construct (GType object_type, GtkApplication* app) {
	BoxesAppWindow * self = NULL;
	GtkApplication* _tmp0_;
	GSettings* _tmp1_;
	GtkSettings* _tmp2_;
	GtkCssProvider* provider = NULL;
	GtkCssProvider* _tmp3_;
	GdkScreen* _tmp4_;
	GtkCssProvider* _tmp5_;
	GVariant* size = NULL;
	GSettings* _tmp6_;
	GVariant* _tmp7_;
	GVariant* _tmp8_;
	gsize _tmp9_;
	GSettings* _tmp22_;
	gboolean _tmp23_;
	GVariant* position = NULL;
	GSettings* _tmp24_;
	GVariant* _tmp25_;
	GVariant* _tmp26_;
	gsize _tmp27_;
	BoxesIconView* _tmp40_;
	BoxesICollectionView* _tmp41_;
	BoxesListView* _tmp42_;
	BoxesICollectionView* _tmp43_;
	BoxesICollectionView** _tmp44_;
	GSimpleAction* action = NULL;
	GSimpleAction* _tmp45_;
#line 128 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (app != NULL, NULL);
#line 129 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = app;
#line 129 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) g_object_new (object_type, "application", _tmp0_, "title", _ ("Boxes"), "show-menubar", FALSE, NULL);
#line 134 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = g_settings_new ("org.gnome.boxes");
#line 134 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->settings);
#line 134 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->settings = _tmp1_;
#line 136 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_app_window_ui_state_changed_g_object_notify, self, 0);
#line 138 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_window_set_default_icon_name ("gnome-boxes");
#line 139 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = gtk_settings_get_default ();
#line 139 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_set (_tmp2_, "gtk-application-prefer-dark-theme", TRUE, NULL);
#line 141 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = boxes_load_css ("gtk-style.css");
#line 141 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	provider = _tmp3_;
#line 142 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp4_ = gdk_screen_get_default ();
#line 142 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp5_ = provider;
#line 142 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_style_context_add_provider_for_screen (_tmp4_, (GtkStyleProvider*) _tmp5_, (guint) 600);
#line 147 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp6_ = self->settings;
#line 147 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_ = g_settings_get_value (_tmp6_, "window-size");
#line 147 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	size = _tmp7_;
#line 148 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8_ = size;
#line 148 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp9_ = g_variant_n_children (_tmp8_);
#line 148 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp9_ == ((gsize) 2)) {
#line 801 "app-window.c"
		gint width = 0;
		GVariant* _tmp10_;
		GVariant* _tmp11_;
		GVariant* _tmp12_;
		gint _tmp13_;
		gint _tmp14_;
		gint height = 0;
		GVariant* _tmp15_;
		GVariant* _tmp16_;
		GVariant* _tmp17_;
		gint _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		gint _tmp21_;
#line 149 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp10_ = size;
#line 149 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp11_ = g_variant_get_child_value (_tmp10_, (gsize) 0);
#line 149 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp12_ = _tmp11_;
#line 149 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp13_ = _variant_get1 (_tmp12_);
#line 149 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp14_ = _tmp13_;
#line 149 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_g_variant_unref0 (_tmp12_);
#line 149 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		width = _tmp14_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp15_ = size;
#line 150 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp16_ = g_variant_get_child_value (_tmp15_, (gsize) 1);
#line 150 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp17_ = _tmp16_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp18_ = _variant_get2 (_tmp17_);
#line 150 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp19_ = _tmp18_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_g_variant_unref0 (_tmp17_);
#line 150 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		height = _tmp19_;
#line 152 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp20_ = width;
#line 152 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp21_ = height;
#line 152 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		gtk_window_set_default_size ((GtkWindow*) self, _tmp20_, _tmp21_);
#line 850 "app-window.c"
	}
#line 155 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp22_ = self->settings;
#line 155 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp23_ = g_settings_get_boolean (_tmp22_, "window-maximized");
#line 155 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp23_) {
#line 156 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		gtk_window_maximize ((GtkWindow*) self);
#line 860 "app-window.c"
	}
#line 158 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp24_ = self->settings;
#line 158 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp25_ = g_settings_get_value (_tmp24_, "window-position");
#line 158 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	position = _tmp25_;
#line 159 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp26_ = position;
#line 159 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp27_ = g_variant_n_children (_tmp26_);
#line 159 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp27_ == ((gsize) 2)) {
#line 874 "app-window.c"
		gint x = 0;
		GVariant* _tmp28_;
		GVariant* _tmp29_;
		GVariant* _tmp30_;
		gint _tmp31_;
		gint _tmp32_;
		gint y = 0;
		GVariant* _tmp33_;
		GVariant* _tmp34_;
		GVariant* _tmp35_;
		gint _tmp36_;
		gint _tmp37_;
		gint _tmp38_;
		gint _tmp39_;
#line 160 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp28_ = position;
#line 160 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp29_ = g_variant_get_child_value (_tmp28_, (gsize) 0);
#line 160 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp30_ = _tmp29_;
#line 160 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp31_ = _variant_get3 (_tmp30_);
#line 160 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp32_ = _tmp31_;
#line 160 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_g_variant_unref0 (_tmp30_);
#line 160 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		x = _tmp32_;
#line 161 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp33_ = position;
#line 161 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp34_ = g_variant_get_child_value (_tmp33_, (gsize) 1);
#line 161 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp35_ = _tmp34_;
#line 161 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp36_ = _variant_get4 (_tmp35_);
#line 161 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp37_ = _tmp36_;
#line 161 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_g_variant_unref0 (_tmp35_);
#line 161 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		y = _tmp37_;
#line 163 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp38_ = x;
#line 163 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp39_ = y;
#line 163 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		gtk_window_move ((GtkWindow*) self, _tmp38_, _tmp39_);
#line 923 "app-window.c"
	}
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp40_ = self->priv->icon_view;
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp41_ = _g_object_ref0 ((BoxesICollectionView*) _tmp40_);
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp42_ = self->priv->list_view;
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp43_ = _g_object_ref0 ((BoxesICollectionView*) _tmp42_);
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp44_ = g_new0 (BoxesICollectionView*, 2 + 1);
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp44_[0] = _tmp41_;
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp44_[1] = _tmp43_;
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->views = (_vala_array_free (self->priv->views, self->priv->views_length1, (GDestroyNotify) g_object_unref), NULL);
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->views = _tmp44_;
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->views_length1 = 2;
#line 166 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->_views_size_ = self->priv->views_length1;
#line 168 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp45_ = g_simple_action_new ("kbd-shortcuts", NULL);
#line 168 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	action = _tmp45_;
#line 169 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_signal_connect_object (action, "activate", (GCallback) ___lambda246__g_simple_action_activate, self, 0);
#line 180 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) action);
#line 128 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (action);
#line 128 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_variant_unref0 (position);
#line 128 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_variant_unref0 (size);
#line 128 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (provider);
#line 128 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return self;
#line 965 "app-window.c"
}


BoxesAppWindow* boxes_app_window_new (GtkApplication* app) {
#line 128 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return boxes_app_window_construct (BOXES_TYPE_APP_WINDOW, app);
#line 972 "app-window.c"
}


void boxes_app_window_setup_ui (BoxesAppWindow* self) {
	BoxesTopbar* _tmp0_;
	BoxesDisplayPage* _tmp1_;
	BoxesIconView* _tmp2_;
	BoxesListView* _tmp3_;
	BoxesSelectionbar* _tmp4_;
	BoxesSearchbar* _tmp5_;
	BoxesEmptyBoxes* _tmp6_;
	BoxesNotificationbar* _tmp7_;
	BoxesNotificationbar* _tmp8_;
	BoxesSearchbar* _tmp9_;
	BoxesSearchbar* _tmp10_;
	GtkWindowGroup* _tmp11_;
	BoxesWizardWindow* _tmp12_;
	GtkWindowGroup* _tmp13_;
	BoxesWizardWindow* _tmp14_;
	BoxesPropertiesWindow* _tmp15_;
	GtkWindowGroup* _tmp16_;
	BoxesPropertiesWindow* _tmp17_;
#line 183 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 184 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->topbar;
#line 184 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_topbar_setup_ui (_tmp0_, self);
#line 185 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = self->display_page;
#line 185 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_display_page_setup_ui (_tmp1_, self);
#line 186 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = self->priv->icon_view;
#line 186 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_icon_view_setup_ui (_tmp2_, self);
#line 187 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = self->priv->list_view;
#line 187 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_list_view_setup_ui (_tmp3_, self);
#line 188 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp4_ = self->selectionbar;
#line 188 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_selectionbar_setup_ui (_tmp4_, self);
#line 189 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp5_ = self->searchbar;
#line 189 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_searchbar_setup_ui (_tmp5_, self);
#line 190 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp6_ = self->empty_boxes;
#line 190 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_empty_boxes_setup_ui (_tmp6_, self);
#line 191 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_ = boxes_app_window_get_notificationbar (self);
#line 191 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8_ = _tmp7_;
#line 191 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp9_ = self->searchbar;
#line 191 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp10_ = _g_object_ref0 (_tmp9_);
#line 191 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (_tmp8_->searchbar);
#line 191 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8_->searchbar = _tmp10_;
#line 193 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp11_ = gtk_window_group_new ();
#line 193 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->group);
#line 193 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->group = _tmp11_;
#line 194 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_ = boxes_wizard_window_new (self);
#line 194 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_ref_sink (_tmp12_);
#line 194 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->wizard_window);
#line 194 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->wizard_window = _tmp12_;
#line 195 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp13_ = self->priv->group;
#line 195 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp14_ = self->wizard_window;
#line 195 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_window_group_add_window (_tmp13_, (GtkWindow*) _tmp14_);
#line 196 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp15_ = boxes_properties_window_new (self);
#line 196 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_ref_sink (_tmp15_);
#line 196 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->props_window);
#line 196 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->props_window = _tmp15_;
#line 197 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp16_ = self->priv->group;
#line 197 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp17_ = self->props_window;
#line 197 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_window_group_add_window (_tmp16_, (GtkWindow*) _tmp17_);
#line 199 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_signal_connect_object ((GObject*) self, "notify::view-type", (GCallback) _boxes_app_window_ui_state_changed_g_object_notify, self, 0);
#line 1073 "app-window.c"
}


static GVariant* _variant_new5 (gint* value, gint value_length1) {
	gint* _tmp9_;
	GVariantBuilder _tmp10_;
	int _tmp11_;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp9_ = value;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_variant_builder_init (&_tmp10_, G_VARIANT_TYPE ("ai"));
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	for (_tmp11_ = 0; _tmp11_ < value_length1; _tmp11_++) {
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_variant_builder_add_value (&_tmp10_, g_variant_new_int32 (*_tmp9_));
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp9_++;
#line 1091 "app-window.c"
	}
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return g_variant_ref_sink (g_variant_builder_end (&_tmp10_));
#line 1095 "app-window.c"
}


static GVariant* _variant_new6 (gint* value, gint value_length1) {
	gint* _tmp20_;
	GVariantBuilder _tmp21_;
	int _tmp22_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp20_ = value;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_variant_builder_init (&_tmp21_, G_VARIANT_TYPE ("ai"));
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	for (_tmp22_ = 0; _tmp22_ < value_length1; _tmp22_++) {
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_variant_builder_add_value (&_tmp21_, g_variant_new_int32 (*_tmp20_));
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp20_++;
#line 1113 "app-window.c"
	}
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return g_variant_ref_sink (g_variant_builder_end (&_tmp21_));
#line 1117 "app-window.c"
}


static void boxes_app_window_save_window_geometry (BoxesAppWindow* self) {
	gint width = 0;
	gint height = 0;
	gint x = 0;
	gint y = 0;
	gboolean _tmp0_;
	gboolean _tmp1_;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	GSettings* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	gint* _tmp7_;
	gint* _tmp8_;
	gint _tmp8__length1;
	GVariant* _tmp12_;
	gint _tmp13_ = 0;
	gint _tmp14_ = 0;
	GSettings* _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	gint* _tmp18_;
	gint* _tmp19_;
	gint _tmp19__length1;
	GVariant* _tmp23_;
#line 202 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 205 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_app_window_get_maximized (self);
#line 205 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 205 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp1_) {
#line 206 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		return;
#line 1156 "app-window.c"
	}
#line 208 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_window_get_size ((GtkWindow*) self, &_tmp2_, &_tmp3_);
#line 208 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	width = _tmp2_;
#line 208 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	height = _tmp3_;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp4_ = self->settings;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp5_ = width;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp6_ = height;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_ = g_new0 (gint, 2);
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_[0] = _tmp5_;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_[1] = _tmp6_;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8_ = _tmp7_;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8__length1 = 2;
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_ = _variant_new5 (_tmp8_, 2);
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_settings_set_value (_tmp4_, "window-size", _tmp12_);
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_variant_unref0 (_tmp12_);
#line 209 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8_ = (g_free (_tmp8_), NULL);
#line 211 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_window_get_position ((GtkWindow*) self, &_tmp13_, &_tmp14_);
#line 211 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	x = _tmp13_;
#line 211 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	y = _tmp14_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp15_ = self->settings;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp16_ = x;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp17_ = y;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp18_ = g_new0 (gint, 2);
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp18_[0] = _tmp16_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp18_[1] = _tmp17_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp19_ = _tmp18_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp19__length1 = 2;
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp23_ = _variant_new6 (_tmp19_, 2);
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_settings_set_value (_tmp15_, "window-position", _tmp23_);
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_variant_unref0 (_tmp23_);
#line 212 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp19_ = (g_free (_tmp19_), NULL);
#line 1218 "app-window.c"
}


static void ___lambda223_ (BoxesAppWindow* self, BoxesICollectionView* view) {
	BoxesICollectionView* _tmp0_;
#line 239 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (view != NULL);
#line 239 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = view;
#line 239 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, TRUE);
#line 1230 "app-window.c"
}


static void ____lambda223__gfunc (gconstpointer data, gpointer self) {
#line 239 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	___lambda223_ ((BoxesAppWindow*) self, (BoxesICollectionView*) data);
#line 1237 "app-window.c"
}


static void boxes_app_window_ui_state_changed (BoxesAppWindow* self) {
	BoxesTopbar* _tmp0_;
	BoxesUI* _tmp1_;
	BoxesIconView* _tmp2_;
	BoxesUI* _tmp3_;
	BoxesListView* _tmp4_;
	BoxesUI* _tmp5_;
	BoxesPropertiesWindow* _tmp6_;
	BoxesUI* _tmp7_;
	BoxesWizardWindow* _tmp8_;
	BoxesUI* _tmp9_;
	BoxesEmptyBoxes* _tmp10_;
	BoxesUI* _tmp11_;
	BoxesUI** _tmp12_;
	BoxesUIState _tmp17_;
	BoxesUIState _tmp18_;
	BoxesMachine* _tmp20_ = NULL;
	BoxesCollectionItem* _tmp21_;
	BoxesCollectionItem* _tmp22_;
	BoxesMachine* machine = NULL;
	BoxesMachine* _tmp25_;
	BoxesUIState _tmp26_;
	BoxesUIState _tmp27_;
	gboolean _tmp61_ = FALSE;
	BoxesMachine* _tmp62_;
#line 215 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->topbar;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = _g_object_ref0 ((BoxesUI*) _tmp0_);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = self->priv->icon_view;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = _g_object_ref0 ((BoxesUI*) _tmp2_);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp4_ = self->priv->list_view;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp5_ = _g_object_ref0 ((BoxesUI*) _tmp4_);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp6_ = self->props_window;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_ = _g_object_ref0 ((BoxesUI*) _tmp6_);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8_ = self->wizard_window;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp9_ = _g_object_ref0 ((BoxesUI*) _tmp8_);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp10_ = self->empty_boxes;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp11_ = _g_object_ref0 ((BoxesUI*) _tmp10_);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_ = g_new0 (BoxesUI*, 6 + 1);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_[0] = _tmp1_;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_[1] = _tmp3_;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_[2] = _tmp5_;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_[3] = _tmp7_;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_[4] = _tmp9_;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_[5] = _tmp11_;
#line 1306 "app-window.c"
	{
		BoxesUI** ui_collection = NULL;
		gint ui_collection_length1 = 0;
		gint _ui_collection_size_ = 0;
		gint ui_it = 0;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		ui_collection = _tmp12_;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		ui_collection_length1 = 6;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		for (ui_it = 0; ui_it < 6; ui_it = ui_it + 1) {
#line 1318 "app-window.c"
			BoxesUI* _tmp13_;
			BoxesUI* ui = NULL;
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp13_ = _g_object_ref0 (ui_collection[ui_it]);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			ui = _tmp13_;
#line 1325 "app-window.c"
			{
				BoxesUI* _tmp14_;
				BoxesUIState _tmp15_;
				BoxesUIState _tmp16_;
#line 224 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp14_ = ui;
#line 224 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp15_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 224 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp16_ = _tmp15_;
#line 224 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				boxes_ui_set_state (_tmp14_, _tmp16_);
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_g_object_unref0 (ui);
#line 1340 "app-window.c"
			}
		}
#line 218 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		ui_collection = (_vala_array_free (ui_collection, ui_collection_length1, (GDestroyNotify) g_object_unref), NULL);
#line 1345 "app-window.c"
	}
#line 227 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp17_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 227 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp18_ = _tmp17_;
#line 227 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp18_ != BOXES_UI_STATE_COLLECTION) {
#line 1353 "app-window.c"
		BoxesSearchbar* _tmp19_;
#line 228 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp19_ = self->searchbar;
#line 228 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_object_set ((GtkSearchBar*) _tmp19_, "search-mode-enabled", FALSE, NULL);
#line 1359 "app-window.c"
	}
#line 230 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp21_ = boxes_app_window_get_current_item (self);
#line 230 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp22_ = _tmp21_;
#line 230 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, BOXES_TYPE_MACHINE)) {
#line 1367 "app-window.c"
		BoxesCollectionItem* _tmp23_;
		BoxesCollectionItem* _tmp24_;
#line 230 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp23_ = boxes_app_window_get_current_item (self);
#line 230 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp24_ = _tmp23_;
#line 230 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp20_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp24_) : NULL;
#line 1376 "app-window.c"
	} else {
#line 230 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp20_ = NULL;
#line 1380 "app-window.c"
	}
#line 230 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp25_ = _g_object_ref0 (_tmp20_);
#line 230 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	machine = _tmp25_;
#line 232 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp26_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 232 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp27_ = _tmp26_;
#line 232 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	switch (_tmp27_) {
#line 232 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 1394 "app-window.c"
		{
			BoxesApp* _tmp28_;
			BoxesCollection* _tmp29_;
			guint _tmp30_;
			guint _tmp31_;
			GBinding* _tmp37_;
			BoxesTopbar* _tmp40_;
			AtkObject* a11y = NULL;
			AtkObject* _tmp41_;
			AtkObject* _tmp42_;
			AtkObject* _tmp43_;
			BoxesMachine* _tmp44_;
#line 234 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp28_ = boxes_app_app;
#line 234 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp29_ = _tmp28_->collection;
#line 234 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp30_ = boxes_collection_get_length (_tmp29_);
#line 234 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp31_ = _tmp30_;
#line 234 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			if (_tmp31_ != ((guint) 0)) {
#line 1417 "app-window.c"
				GtkStack* _tmp32_;
				BoxesICollectionView* _tmp33_;
				BoxesICollectionView* _tmp34_;
#line 235 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp32_ = self->below_bin;
#line 235 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp33_ = boxes_app_window_get_view (self);
#line 235 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp34_ = _tmp33_;
#line 235 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				gtk_stack_set_visible_child (_tmp32_, (GtkWidget*) _tmp34_);
#line 1429 "app-window.c"
			} else {
				GtkStack* _tmp35_;
				BoxesEmptyBoxes* _tmp36_;
#line 237 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp35_ = self->below_bin;
#line 237 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp36_ = self->empty_boxes;
#line 237 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				gtk_stack_set_visible_child (_tmp35_, (GtkWidget*) _tmp36_);
#line 1439 "app-window.c"
			}
#line 238 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			boxes_app_window_set_fullscreened (self, FALSE);
#line 239 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			boxes_app_window_foreach_view (self, ____lambda223__gfunc, self);
#line 241 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp37_ = self->priv->status_bind;
#line 241 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			if (_tmp37_ != NULL) {
#line 1449 "app-window.c"
				GBinding* _tmp38_;
				GBinding* _tmp39_;
#line 242 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp38_ = self->priv->status_bind;
#line 242 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp39_ = _g_object_ref0 (_tmp38_);
#line 242 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				g_binding_unbind (_tmp39_);
#line 243 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_g_object_unref0 (self->priv->status_bind);
#line 243 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				self->priv->status_bind = NULL;
#line 1462 "app-window.c"
			}
#line 245 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp40_ = self->topbar;
#line 245 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			boxes_topbar_set_status (_tmp40_, _ ("Boxes"));
#line 246 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp41_ = gtk_widget_get_accessible ((GtkWidget*) self);
#line 246 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp42_ = _g_object_ref0 (_tmp41_);
#line 246 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			a11y = _tmp42_;
#line 247 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp43_ = a11y;
#line 247 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			g_object_set (_tmp43_, "accessible-name", _ ("Boxes"), NULL);
#line 249 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp44_ = machine;
#line 249 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			if (_tmp44_ != NULL) {
#line 1482 "app-window.c"
				gulong _tmp45_;
				BoxesMachine* _tmp48_;
				GCancellable* _tmp49_;
				GCancellable* _tmp50_;
				BoxesMachine* _tmp51_;
#line 250 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp45_ = self->priv->got_error_id;
#line 250 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				if (_tmp45_ != ((gulong) 0)) {
#line 1492 "app-window.c"
					BoxesMachine* _tmp46_;
					gulong _tmp47_;
#line 251 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp46_ = machine;
#line 251 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp47_ = self->priv->got_error_id;
#line 251 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					g_signal_handler_disconnect ((GObject*) _tmp46_, _tmp47_);
#line 252 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					self->priv->got_error_id = (gulong) 0;
#line 1503 "app-window.c"
				}
#line 255 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp48_ = machine;
#line 255 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp49_ = boxes_machine_get_connecting_cancellable (_tmp48_);
#line 255 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp50_ = _tmp49_;
#line 255 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				g_cancellable_cancel (_tmp50_);
#line 256 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp51_ = machine;
#line 256 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				boxes_machine_schedule_autosave (_tmp51_);
#line 1517 "app-window.c"
			}
#line 259 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_g_object_unref0 (a11y);
#line 259 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			break;
#line 1523 "app-window.c"
		}
#line 232 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_CREDS:
#line 232 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 232 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_WIZARD:
#line 232 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 1533 "app-window.c"
		{
			BoxesCollectionItem* _tmp52_;
			BoxesCollectionItem* _tmp53_;
#line 265 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp52_ = boxes_app_window_get_current_item (self);
#line 265 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp53_ = _tmp52_;
#line 265 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			if (_tmp53_ != NULL) {
#line 1543 "app-window.c"
				BoxesCollectionItem* _tmp54_;
				BoxesCollectionItem* _tmp55_;
#line 266 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp54_ = boxes_app_window_get_current_item (self);
#line 266 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp55_ = _tmp54_;
#line 266 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				boxes_machine_unschedule_autosave (G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp55_) : NULL);
#line 1552 "app-window.c"
			}
#line 268 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			break;
#line 1556 "app-window.c"
		}
		default:
		{
			BoxesUIState _tmp56_;
			BoxesUIState _tmp57_;
			GEnumValue* _tmp58_;
			gchar* _tmp59_;
			gchar* _tmp60_;
#line 271 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp56_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 271 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp57_ = _tmp56_;
#line 271 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp58_ = g_enum_get_value (g_type_class_ref (BOXES_TYPE_UI_STATE), _tmp57_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp59_ = g_strdup_printf ("Unhandled UI state %s", (_tmp58_ != NULL) ? _tmp58_->value_name : NULL);
#line 271 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp60_ = _tmp59_;
#line 271 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			g_warning ("app-window.vala:271: %s", _tmp60_);
#line 271 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_g_free0 (_tmp60_);
#line 272 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			break;
#line 1581 "app-window.c"
		}
	}
#line 275 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp62_ = machine;
#line 275 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp62_ != NULL) {
#line 1588 "app-window.c"
		BoxesMachine* _tmp63_;
		BoxesAppWindow* _tmp64_;
		BoxesAppWindow* _tmp65_;
#line 275 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp63_ = machine;
#line 275 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp64_ = boxes_machine_get_window (_tmp63_);
#line 275 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp65_ = _tmp64_;
#line 275 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp61_ = self == _tmp65_;
#line 1600 "app-window.c"
	} else {
#line 275 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp61_ = FALSE;
#line 1604 "app-window.c"
	}
#line 275 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp61_) {
#line 1608 "app-window.c"
		BoxesCollectionItem* _tmp66_;
		BoxesCollectionItem* _tmp67_;
		BoxesUIState _tmp68_;
		BoxesUIState _tmp69_;
#line 276 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp66_ = boxes_app_window_get_current_item (self);
#line 276 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp67_ = _tmp66_;
#line 276 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp68_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 276 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp69_ = _tmp68_;
#line 276 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_ui_set_state ((BoxesUI*) _tmp67_, _tmp69_);
#line 1623 "app-window.c"
	}
#line 215 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (machine);
#line 1627 "app-window.c"
}


void boxes_app_window_foreach_view (BoxesAppWindow* self, GFunc func, void* func_target) {
	BoxesICollectionView** _tmp0_;
	gint _tmp0__length1;
#line 279 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 280 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->views;
#line 280 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0__length1 = self->priv->views_length1;
#line 1640 "app-window.c"
	{
		BoxesICollectionView** view_collection = NULL;
		gint view_collection_length1 = 0;
		gint _view_collection_size_ = 0;
		gint view_it = 0;
#line 280 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		view_collection = _tmp0_;
#line 280 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		view_collection_length1 = _tmp0__length1;
#line 280 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		for (view_it = 0; view_it < _tmp0__length1; view_it = view_it + 1) {
#line 1652 "app-window.c"
			BoxesICollectionView* _tmp1_;
			BoxesICollectionView* view = NULL;
#line 280 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp1_ = _g_object_ref0 (view_collection[view_it]);
#line 280 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			view = _tmp1_;
#line 1659 "app-window.c"
			{
				GFunc _tmp2_;
				void* _tmp2__target;
				BoxesICollectionView* _tmp3_;
#line 281 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp2_ = func;
#line 281 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp2__target = func_target;
#line 281 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp3_ = view;
#line 281 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp2_ (_tmp3_, _tmp2__target);
#line 280 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_g_object_unref0 (view);
#line 1674 "app-window.c"
			}
		}
	}
}


static void _g_object_unref0_ (gpointer var) {
#line 284 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1684 "app-window.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 284 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 1691 "app-window.c"
}


void boxes_app_window_show_properties (BoxesAppWindow* self) {
	BoxesCollectionItem* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	GList* selected_items = NULL;
	BoxesICollectionView* _tmp7_;
	BoxesICollectionView* _tmp8_;
	GList* _tmp9_;
	gboolean _tmp10_ = FALSE;
	BoxesUIState _tmp11_;
	BoxesUIState _tmp12_;
	GList* _tmp15_;
#line 284 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 285 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_app_window_get_current_item (self);
#line 285 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 285 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp1_ != NULL) {
#line 1714 "app-window.c"
		gboolean _tmp2_ = FALSE;
		BoxesUIState _tmp3_;
		BoxesUIState _tmp4_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp3_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 286 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp4_ = _tmp3_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		if (_tmp4_ == BOXES_UI_STATE_COLLECTION) {
#line 1724 "app-window.c"
			gboolean _tmp5_;
			gboolean _tmp6_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp5_ = boxes_app_window_get_selection_mode (self);
#line 286 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp6_ = _tmp5_;
#line 286 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp2_ = _tmp6_;
#line 1733 "app-window.c"
		} else {
#line 286 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp2_ = FALSE;
#line 1737 "app-window.c"
		}
#line 286 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		if (_tmp2_) {
#line 287 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			boxes_app_window_set_selection_mode (self, FALSE);
#line 1743 "app-window.c"
		}
#line 288 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_PROPERTIES);
#line 290 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		return;
#line 1749 "app-window.c"
	}
#line 293 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_ = boxes_app_window_get_view (self);
#line 293 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8_ = _tmp7_;
#line 293 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp9_ = boxes_icollection_view_get_selected_items (_tmp8_);
#line 293 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	selected_items = _tmp9_;
#line 295 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp11_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 295 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_ = _tmp11_;
#line 295 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp12_ == BOXES_UI_STATE_COLLECTION) {
#line 1765 "app-window.c"
		gboolean _tmp13_;
		gboolean _tmp14_;
#line 295 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp13_ = boxes_app_window_get_selection_mode (self);
#line 295 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp14_ = _tmp13_;
#line 295 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp10_ = _tmp14_;
#line 1774 "app-window.c"
	} else {
#line 295 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp10_ = FALSE;
#line 1778 "app-window.c"
	}
#line 295 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp10_) {
#line 296 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_selection_mode (self, FALSE);
#line 1784 "app-window.c"
	}
#line 299 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp15_ = selected_items;
#line 1788 "app-window.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 299 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		item_collection = _tmp15_;
#line 299 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1796 "app-window.c"
			BoxesCollectionItem* _tmp16_;
			BoxesCollectionItem* item = NULL;
#line 299 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp16_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 299 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			item = _tmp16_;
#line 1803 "app-window.c"
			{
				BoxesCollectionItem* _tmp17_;
#line 300 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp17_ = item;
#line 300 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				boxes_app_window_set_current_item (self, _tmp17_);
#line 301 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_PROPERTIES);
#line 302 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_g_object_unref0 (item);
#line 302 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				break;
#line 1816 "app-window.c"
			}
		}
	}
#line 284 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	__g_list_free__g_object_unref0_0 (selected_items);
#line 1822 "app-window.c"
}


static void __lambda55_ (BoxesAppWindow* self, const gchar* message) {
	BoxesNotificationbar* _tmp0_;
	BoxesNotificationbar* _tmp1_;
	const gchar* _tmp2_;
	BoxesNotification* _tmp3_;
	BoxesNotification* _tmp4_;
#line 317 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (message != NULL);
#line 318 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_app_window_get_notificationbar (self);
#line 318 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 318 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = message;
#line 318 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = boxes_notificationbar_display_error (_tmp1_, _tmp2_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 318 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp4_ = _tmp3_;
#line 318 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (_tmp4_);
#line 1846 "app-window.c"
}


static void ___lambda55__boxes_machine_got_error (BoxesMachine* _sender, const gchar* message, gpointer self) {
#line 317 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	__lambda55_ ((BoxesAppWindow*) self, message);
#line 1853 "app-window.c"
}


void boxes_app_window_connect_to (BoxesAppWindow* self, BoxesMachine* machine) {
	BoxesMachine* _tmp0_;
	BoxesMachine* _tmp1_;
	BoxesMachine* _tmp2_;
	AtkObject* a11y = NULL;
	AtkObject* _tmp3_;
	AtkObject* _tmp4_;
	AtkObject* _tmp5_;
	BoxesMachine* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	BoxesMachine* _tmp9_;
	BoxesTopbar* _tmp10_;
	GBinding* _tmp11_;
	GBinding* _tmp12_;
	BoxesMachine* _tmp13_;
	gulong _tmp14_;
	BoxesUIState _tmp15_;
	BoxesUIState _tmp16_;
#line 306 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 306 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (machine != NULL);
#line 307 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = machine;
#line 307 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_set_current_item (self, (BoxesCollectionItem*) _tmp0_);
#line 308 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = machine;
#line 308 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_machine_set_window (_tmp1_, self);
#line 309 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = machine;
#line 309 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_machine_unschedule_autosave (_tmp2_);
#line 311 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = gtk_widget_get_accessible ((GtkWidget*) self);
#line 311 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 311 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	a11y = _tmp4_;
#line 312 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp5_ = a11y;
#line 312 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp6_ = machine;
#line 312 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp6_);
#line 312 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8_ = _tmp7_;
#line 312 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_set (_tmp5_, "accessible-name", _tmp8_, NULL);
#line 315 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp9_ = machine;
#line 315 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp10_ = self->topbar;
#line 315 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp11_ = g_object_bind_property_with_closures ((GObject*) _tmp9_, "status", (GObject*) _tmp10_, "status", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 315 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_ = _g_object_ref0 (_tmp11_);
#line 315 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->status_bind);
#line 315 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->status_bind = _tmp12_;
#line 317 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp13_ = machine;
#line 317 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp14_ = g_signal_connect_object (_tmp13_, "got-error", (GCallback) ___lambda55__boxes_machine_got_error, self, 0);
#line 317 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->got_error_id = _tmp14_;
#line 321 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp15_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 321 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp16_ = _tmp15_;
#line 321 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp16_ != BOXES_UI_STATE_CREDS) {
#line 322 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_CREDS);
#line 1934 "app-window.c"
	}
#line 306 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (a11y);
#line 1938 "app-window.c"
}


void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item) {
	gboolean _tmp0_ = FALSE;
	BoxesUIState _tmp1_;
	BoxesUIState _tmp2_;
	BoxesCollectionItem* _tmp5_;
	BoxesMachine* machine = NULL;
	BoxesCollectionItem* _tmp6_;
	BoxesMachine* _tmp7_;
	BoxesMachine* _tmp8_;
	BoxesAppWindow* _tmp9_;
	BoxesAppWindow* _tmp10_;
	BoxesApp* _tmp11_;
	BoxesAppWindow* _tmp12_;
	BoxesAppWindow* _tmp13_;
	BoxesCollectionItem* _tmp17_;
	BoxesCollectionItem* _tmp18_;
	BoxesCollectionItem* _tmp19_;
	BoxesCollectionItem* _tmp21_;
#line 325 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 325 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (item != NULL);
#line 326 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 326 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = _tmp1_;
#line 326 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp2_ != BOXES_UI_STATE_COLLECTION) {
#line 326 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = TRUE;
#line 1972 "app-window.c"
	} else {
		gboolean _tmp3_;
		gboolean _tmp4_;
#line 326 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp3_ = boxes_app_window_get_selection_mode (self);
#line 326 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp4_ = _tmp3_;
#line 326 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = _tmp4_;
#line 1982 "app-window.c"
	}
#line 326 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp0_) {
#line 327 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		return;
#line 1988 "app-window.c"
	}
#line 329 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp5_ = item;
#line 329 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE));
#line 331 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp6_ = item;
#line 331 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp6_) : NULL);
#line 331 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	machine = _tmp7_;
#line 333 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp8_ = machine;
#line 333 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp9_ = boxes_machine_get_window (_tmp8_);
#line 333 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp10_ = _tmp9_;
#line 333 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp11_ = boxes_app_app;
#line 333 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp12_ = boxes_app_get_main_window (_tmp11_);
#line 333 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp13_ = _tmp12_;
#line 333 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp10_ != _tmp13_) {
#line 2014 "app-window.c"
		BoxesMachine* _tmp14_;
		BoxesAppWindow* _tmp15_;
		BoxesAppWindow* _tmp16_;
#line 334 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp14_ = machine;
#line 334 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp15_ = boxes_machine_get_window (_tmp14_);
#line 334 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp16_ = _tmp15_;
#line 334 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		gtk_window_present ((GtkWindow*) _tmp16_);
#line 336 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_g_object_unref0 (machine);
#line 336 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		return;
#line 2030 "app-window.c"
	}
#line 339 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp17_ = item;
#line 339 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_set_current_item (self, _tmp17_);
#line 341 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp18_ = boxes_app_window_get_current_item (self);
#line 341 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp19_ = _tmp18_;
#line 341 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, BOXES_TYPE_MACHINE)) {
#line 2042 "app-window.c"
		BoxesMachine* _tmp20_;
#line 342 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp20_ = machine;
#line 342 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_app_window_connect_to (self, _tmp20_);
#line 2048 "app-window.c"
	} else {
#line 344 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_warning ("app-window.vala:344: unknown item, fix your code");
#line 2052 "app-window.c"
	}
#line 346 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp21_ = item;
#line 346 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_signal_emit (self, boxes_app_window_signals[BOXES_APP_WINDOW_ITEM_SELECTED_SIGNAL], 0, _tmp21_);
#line 325 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (machine);
#line 2060 "app-window.c"
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return _data9_;
#line 2069 "app-window.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 2078 "app-window.c"
		BoxesAppWindow* self;
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self = _data9_->self;
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_g_free0 (_data9_->text);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_g_object_unref0 (self);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_slice_free (Block9Data, _data9_);
#line 2088 "app-window.c"
	}
}


static void __lambda13_ (Block9Data* _data9_, BoxesICollectionView* view) {
	BoxesAppWindow* self;
	BoxesICollectionView* _tmp0_;
	BoxesCollectionFilter* _tmp1_;
	BoxesCollectionFilter* _tmp2_;
	const gchar* _tmp3_;
#line 350 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self = _data9_->self;
#line 350 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (view != NULL);
#line 350 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = view;
#line 350 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_icollection_view_get_filter (_tmp0_);
#line 350 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = _tmp1_;
#line 350 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = _data9_->text;
#line 350 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_collection_filter_set_text (_tmp2_, _tmp3_);
#line 2113 "app-window.c"
}


static void ___lambda13__gfunc (gconstpointer data, gpointer self) {
#line 350 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	__lambda13_ (self, (BoxesICollectionView*) data);
#line 2120 "app-window.c"
}


void boxes_app_window_filter (BoxesAppWindow* self, const gchar* text) {
	Block9Data* _data9_;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (text != NULL);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_data9_->_ref_count_ = 1;
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_data9_->self = g_object_ref (self);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = text;
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_free0 (_data9_->text);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_data9_->text = _tmp1_;
#line 350 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_foreach_view (self, ___lambda13__gfunc, _data9_);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	block9_data_unref (_data9_);
#line 349 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_data9_ = NULL;
#line 2152 "app-window.c"
}


gboolean boxes_app_window_on_key_pressed (BoxesAppWindow* self, GtkWidget* widget, GdkEventKey* event) {
	gboolean result = FALSE;
	GdkModifierType default_modifiers = 0;
	GdkModifierType _tmp0_;
	GtkTextDirection direction = 0;
	GtkTextDirection _tmp1_;
	GdkEventKey* _tmp2_;
	guint _tmp3_;
#line 354 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 354 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 354 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 355 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = gtk_accelerator_get_default_mod_mask ();
#line 355 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	default_modifiers = _tmp0_;
#line 356 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = gtk_widget_get_direction ((GtkWidget*) self);
#line 356 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	direction = _tmp1_;
#line 358 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = event;
#line 358 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = _tmp2_->keyval;
#line 358 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp3_ == ((guint) GDK_KEY_F11)) {
#line 2184 "app-window.c"
		gboolean _tmp4_;
		gboolean _tmp5_;
#line 359 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp4_ = boxes_app_window_get_fullscreened (self);
#line 359 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp5_ = _tmp4_;
#line 359 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_fullscreened (self, !_tmp5_);
#line 361 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		result = TRUE;
#line 361 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		return result;
#line 2197 "app-window.c"
	} else {
		GdkEventKey* _tmp6_;
		guint _tmp7_;
#line 362 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp6_ = event;
#line 362 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp7_ = _tmp6_->keyval;
#line 362 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		if (_tmp7_ == ((guint) GDK_KEY_F1)) {
#line 2207 "app-window.c"
			BoxesApp* _tmp8_;
#line 363 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp8_ = boxes_app_app;
#line 363 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			g_action_group_activate_action ((GActionGroup*) _tmp8_, "help", NULL);
#line 365 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			result = TRUE;
#line 365 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			return result;
#line 2217 "app-window.c"
		} else {
			gboolean _tmp9_ = FALSE;
			GdkEventKey* _tmp10_;
			guint _tmp11_;
#line 366 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp10_ = event;
#line 366 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp11_ = _tmp10_->keyval;
#line 366 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			if (_tmp11_ == ((guint) GDK_KEY_k)) {
#line 2228 "app-window.c"
				GdkEventKey* _tmp12_;
				GdkModifierType _tmp13_;
				GdkModifierType _tmp14_;
#line 367 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp12_ = event;
#line 367 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp13_ = _tmp12_->state;
#line 367 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp14_ = default_modifiers;
#line 367 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp9_ = (_tmp13_ & _tmp14_) == GDK_CONTROL_MASK;
#line 2240 "app-window.c"
			} else {
#line 366 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp9_ = FALSE;
#line 2244 "app-window.c"
			}
#line 366 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			if (_tmp9_) {
#line 368 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				g_action_group_activate_action ((GActionGroup*) self, "kbd-shortcuts", NULL);
#line 370 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				result = TRUE;
#line 370 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				return result;
#line 2254 "app-window.c"
			} else {
				gboolean _tmp15_ = FALSE;
				GdkEventKey* _tmp16_;
				guint _tmp17_;
#line 371 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp16_ = event;
#line 371 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				_tmp17_ = _tmp16_->keyval;
#line 371 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				if (_tmp17_ == ((guint) GDK_KEY_q)) {
#line 2265 "app-window.c"
					GdkEventKey* _tmp18_;
					GdkModifierType _tmp19_;
					GdkModifierType _tmp20_;
#line 372 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp18_ = event;
#line 372 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp19_ = _tmp18_->state;
#line 372 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp20_ = default_modifiers;
#line 372 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp15_ = (_tmp19_ & _tmp20_) == GDK_CONTROL_MASK;
#line 2277 "app-window.c"
				} else {
#line 371 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp15_ = FALSE;
#line 2281 "app-window.c"
				}
#line 371 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
				if (_tmp15_) {
#line 2285 "app-window.c"
					BoxesApp* _tmp21_;
#line 373 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp21_ = boxes_app_app;
#line 373 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					boxes_app_quit_app (_tmp21_);
#line 375 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					result = TRUE;
#line 375 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					return result;
#line 2295 "app-window.c"
				} else {
					gboolean _tmp22_ = FALSE;
					GdkEventKey* _tmp23_;
					guint _tmp24_;
#line 376 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp23_ = event;
#line 376 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					_tmp24_ = _tmp23_->keyval;
#line 376 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					if (_tmp24_ == ((guint) GDK_KEY_n)) {
#line 2306 "app-window.c"
						GdkEventKey* _tmp25_;
						GdkModifierType _tmp26_;
						GdkModifierType _tmp27_;
#line 377 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						_tmp25_ = event;
#line 377 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						_tmp26_ = _tmp25_->state;
#line 377 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						_tmp27_ = default_modifiers;
#line 377 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						_tmp22_ = (_tmp26_ & _tmp27_) == GDK_CONTROL_MASK;
#line 2318 "app-window.c"
					} else {
#line 376 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						_tmp22_ = FALSE;
#line 2322 "app-window.c"
					}
#line 376 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
					if (_tmp22_) {
#line 2326 "app-window.c"
						BoxesTopbar* _tmp28_;
#line 378 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						_tmp28_ = self->topbar;
#line 378 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						boxes_topbar_click_new_button (_tmp28_);
#line 380 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						result = TRUE;
#line 380 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						return result;
#line 2336 "app-window.c"
					} else {
						gboolean _tmp29_ = FALSE;
						GdkEventKey* _tmp30_;
						guint _tmp31_;
#line 381 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						_tmp30_ = event;
#line 381 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						_tmp31_ = _tmp30_->keyval;
#line 381 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						if (_tmp31_ == ((guint) GDK_KEY_f)) {
#line 2347 "app-window.c"
							GdkEventKey* _tmp32_;
							GdkModifierType _tmp33_;
							GdkModifierType _tmp34_;
#line 382 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							_tmp32_ = event;
#line 382 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							_tmp33_ = _tmp32_->state;
#line 382 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							_tmp34_ = default_modifiers;
#line 382 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							_tmp29_ = (_tmp33_ & _tmp34_) == GDK_CONTROL_MASK;
#line 2359 "app-window.c"
						} else {
#line 381 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							_tmp29_ = FALSE;
#line 2363 "app-window.c"
						}
#line 381 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
						if (_tmp29_) {
#line 2367 "app-window.c"
							BoxesTopbar* _tmp35_;
#line 383 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							_tmp35_ = self->topbar;
#line 383 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							boxes_topbar_click_search_button (_tmp35_);
#line 385 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							result = TRUE;
#line 385 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							return result;
#line 2377 "app-window.c"
						} else {
							gboolean _tmp36_ = FALSE;
							gboolean _tmp37_ = FALSE;
							gboolean _tmp38_ = FALSE;
							GtkTextDirection _tmp39_;
#line 386 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							_tmp39_ = direction;
#line 386 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							if (_tmp39_ == GTK_TEXT_DIR_LTR) {
#line 2387 "app-window.c"
								GdkEventKey* _tmp40_;
								guint _tmp41_;
#line 387 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp40_ = event;
#line 387 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp41_ = _tmp40_->keyval;
#line 387 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp38_ = _tmp41_ == ((guint) GDK_KEY_Left);
#line 2396 "app-window.c"
							} else {
#line 386 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp38_ = FALSE;
#line 2400 "app-window.c"
							}
#line 386 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							if (_tmp38_) {
#line 386 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp37_ = TRUE;
#line 2406 "app-window.c"
							} else {
								gboolean _tmp42_ = FALSE;
								GtkTextDirection _tmp43_;
#line 388 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp43_ = direction;
#line 388 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								if (_tmp43_ == GTK_TEXT_DIR_RTL) {
#line 2414 "app-window.c"
									GdkEventKey* _tmp44_;
									guint _tmp45_;
#line 389 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
									_tmp44_ = event;
#line 389 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
									_tmp45_ = _tmp44_->keyval;
#line 389 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
									_tmp42_ = _tmp45_ == ((guint) GDK_KEY_Right);
#line 2423 "app-window.c"
								} else {
#line 388 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
									_tmp42_ = FALSE;
#line 2427 "app-window.c"
								}
#line 388 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp37_ = _tmp42_;
#line 2431 "app-window.c"
							}
#line 386 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							if (_tmp37_) {
#line 2435 "app-window.c"
								GdkEventKey* _tmp46_;
								GdkModifierType _tmp47_;
								GdkModifierType _tmp48_;
#line 390 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp46_ = event;
#line 390 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp47_ = _tmp46_->state;
#line 390 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp48_ = default_modifiers;
#line 390 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp36_ = (_tmp47_ & _tmp48_) == GDK_MOD1_MASK;
#line 2447 "app-window.c"
							} else {
#line 386 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp36_ = FALSE;
#line 2451 "app-window.c"
							}
#line 386 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
							if (_tmp36_) {
#line 2455 "app-window.c"
								BoxesTopbar* _tmp49_;
#line 391 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp49_ = self->topbar;
#line 391 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								boxes_topbar_click_back_button (_tmp49_);
#line 392 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								result = TRUE;
#line 392 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								return result;
#line 2465 "app-window.c"
							} else {
								GdkEventKey* _tmp50_;
								guint _tmp51_;
#line 393 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp50_ = event;
#line 393 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								_tmp51_ = _tmp50_->keyval;
#line 393 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
								if (_tmp51_ == ((guint) GDK_KEY_Escape)) {
#line 2475 "app-window.c"
									BoxesTopbar* _tmp52_;
#line 394 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
									_tmp52_ = self->topbar;
#line 394 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
									boxes_topbar_click_cancel_button (_tmp52_);
#line 2481 "app-window.c"
								}
							}
						}
					}
				}
			}
		}
	}
#line 397 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = FALSE;
#line 397 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2494 "app-window.c"
}


static gboolean _boxes_app_window_on_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = boxes_app_window_on_key_pressed ((BoxesAppWindow*) self, _sender, event);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2503 "app-window.c"
}


static gboolean __lambda247_ (BoxesAppWindow* self) {
	gboolean result = FALSE;
#line 408 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->configure_id = (guint) 0;
#line 409 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_save_window_geometry (self);
#line 411 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = FALSE;
#line 411 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2517 "app-window.c"
}


static gboolean ___lambda247__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda247_ ((BoxesAppWindow*) self);
#line 407 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2526 "app-window.c"
}


static gboolean boxes_app_window_on_configure_event (BoxesAppWindow* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
	gboolean _tmp1_;
	guint _tmp2_;
	guint _tmp4_;
#line 401 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 402 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_app_window_get_fullscreened (self);
#line 402 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 402 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp1_) {
#line 403 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		result = FALSE;
#line 403 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		return result;
#line 2548 "app-window.c"
	}
#line 405 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = self->priv->configure_id;
#line 405 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 2554 "app-window.c"
		guint _tmp3_;
#line 406 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp3_ = self->priv->configure_id;
#line 406 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_source_remove (_tmp3_);
#line 2560 "app-window.c"
	}
#line 407 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp4_ = g_timeout_add_full (G_PRIORITY_DEFAULT, BOXES_APP_WINDOW_configure_id_timeout, ___lambda247__gsource_func, g_object_ref (self), g_object_unref);
#line 407 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->configure_id = _tmp4_;
#line 414 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = FALSE;
#line 414 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2570 "app-window.c"
}


static gboolean _boxes_app_window_on_configure_event_gtk_widget_configure_event (GtkWidget* _sender, GdkEventConfigure* event, gpointer self) {
	gboolean result;
	result = boxes_app_window_on_configure_event ((BoxesAppWindow*) self);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2579 "app-window.c"
}


static gboolean boxes_app_window_on_window_state_event (BoxesAppWindow* self, GdkEventWindowState* event) {
	gboolean result = FALSE;
	GdkEventWindowState* _tmp0_;
	GdkWindowState _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	GSettings* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 418 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 418 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 419 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = event;
#line 419 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_->changed_mask;
#line 419 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if ((_tmp1_ & GDK_WINDOW_STATE_FULLSCREEN) == GDK_WINDOW_STATE_FULLSCREEN) {
#line 420 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_object_notify ((GObject*) self, "fullscreened");
#line 2604 "app-window.c"
	}
#line 422 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = boxes_app_window_get_fullscreened (self);
#line 422 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = _tmp2_;
#line 422 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp3_) {
#line 423 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		result = FALSE;
#line 423 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		return result;
#line 2616 "app-window.c"
	}
#line 425 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp4_ = self->settings;
#line 425 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp5_ = boxes_app_window_get_maximized (self);
#line 425 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp6_ = _tmp5_;
#line 425 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_settings_set_boolean (_tmp4_, "window-maximized", _tmp6_);
#line 427 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = FALSE;
#line 427 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2630 "app-window.c"
}


static gboolean _boxes_app_window_on_window_state_event_gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self) {
	gboolean result;
	result = boxes_app_window_on_window_state_event ((BoxesAppWindow*) self, event);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2639 "app-window.c"
}


static gboolean boxes_app_window_on_delete_event (BoxesAppWindow* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	BoxesCollectionItem* _tmp1_;
	BoxesCollectionItem* _tmp2_;
	BoxesCollectionItem* _tmp5_;
	BoxesCollectionItem* _tmp6_;
	BoxesApp* _tmp16_;
	gboolean _tmp17_;
#line 431 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 432 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_app_window_get_current_item (self);
#line 432 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = _tmp1_;
#line 432 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp2_ == NULL) {
#line 432 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = TRUE;
#line 2662 "app-window.c"
	} else {
		BoxesCollectionItem* _tmp3_;
		BoxesCollectionItem* _tmp4_;
#line 432 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp3_ = boxes_app_window_get_current_item (self);
#line 432 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp4_ = _tmp3_;
#line 432 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE);
#line 2672 "app-window.c"
	}
#line 432 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (_tmp0_, FALSE);
#line 434 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp5_ = boxes_app_window_get_current_item (self);
#line 434 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp6_ = _tmp5_;
#line 434 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp6_ != NULL) {
#line 2682 "app-window.c"
		BoxesMachine* machine = NULL;
		BoxesCollectionItem* _tmp7_;
		BoxesCollectionItem* _tmp8_;
		BoxesMachine* _tmp9_;
		BoxesMachine* _tmp10_;
		BoxesMachine* _tmp11_;
		BoxesMachine* _tmp12_;
		gulong _tmp13_;
		BoxesMachine* _tmp14_;
		gulong _tmp15_;
#line 435 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp7_ = boxes_app_window_get_current_item (self);
#line 435 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp8_ = _tmp7_;
#line 435 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp8_) : NULL);
#line 435 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		machine = _tmp9_;
#line 437 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp10_ = machine;
#line 437 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_machine_set_window (_tmp10_, NULL);
#line 438 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp11_ = machine;
#line 438 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_machine_schedule_autosave (_tmp11_);
#line 440 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp12_ = machine;
#line 440 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp13_ = self->priv->machine_state_notify_id;
#line 440 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_signal_handler_disconnect ((GObject*) _tmp12_, _tmp13_);
#line 441 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self->priv->machine_state_notify_id = (gulong) 0;
#line 442 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp14_ = machine;
#line 442 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp15_ = self->priv->machine_deleted_notify_id;
#line 442 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_signal_handler_disconnect ((GObject*) _tmp14_, _tmp15_);
#line 443 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self->priv->machine_deleted_notify_id = (gulong) 0;
#line 434 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_g_object_unref0 (machine);
#line 2727 "app-window.c"
	}
#line 446 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp16_ = boxes_app_app;
#line 446 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp17_ = boxes_app_remove_window (_tmp16_, self);
#line 446 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = _tmp17_;
#line 446 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2737 "app-window.c"
}


static gboolean _boxes_app_window_on_delete_event_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = boxes_app_window_on_delete_event ((BoxesAppWindow*) self);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2746 "app-window.c"
}


static void boxes_app_window_on_machine_state_notify (BoxesAppWindow* self) {
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_;
	BoxesAppWindow* _tmp2_;
	BoxesAppWindow* _tmp3_;
#line 449 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_app_app;
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = boxes_app_get_main_window (_tmp1_);
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = _tmp2_;
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (self != _tmp3_) {
#line 2765 "app-window.c"
		BoxesCollectionItem* _tmp4_;
		BoxesCollectionItem* _tmp5_;
		BoxesMachineMachineState _tmp6_;
		BoxesMachineMachineState _tmp7_;
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp4_ = boxes_app_window_get_current_item (self);
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp5_ = _tmp4_;
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp6_ = boxes_machine_get_state (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp7_ = _tmp6_;
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = _tmp7_ != BOXES_MACHINE_MACHINE_STATE_RUNNING;
#line 2780 "app-window.c"
	} else {
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = FALSE;
#line 2784 "app-window.c"
	}
#line 450 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp0_) {
#line 451 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_app_window_on_delete_event (self);
#line 2790 "app-window.c"
	}
}


static void boxes_app_window_on_machine_deleted_notify (BoxesAppWindow* self) {
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_;
	BoxesAppWindow* _tmp2_;
	BoxesAppWindow* _tmp3_;
#line 454 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = boxes_app_app;
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = boxes_app_get_main_window (_tmp1_);
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp3_ = _tmp2_;
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (self != _tmp3_) {
#line 2810 "app-window.c"
		BoxesCollectionItem* _tmp4_;
		BoxesCollectionItem* _tmp5_;
		gboolean _tmp6_;
		gboolean _tmp7_;
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp4_ = boxes_app_window_get_current_item (self);
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp5_ = _tmp4_;
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp6_ = boxes_machine_get_deleted (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp7_ = _tmp6_;
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = _tmp7_;
#line 2825 "app-window.c"
	} else {
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = FALSE;
#line 2829 "app-window.c"
	}
#line 455 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp0_) {
#line 456 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_app_window_on_delete_event (self);
#line 2835 "app-window.c"
	}
}


static BoxesUIState boxes_app_window_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesAppWindow* self;
	BoxesUIState _tmp0_;
#line 14 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) base;
#line 14 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 14 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 14 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2852 "app-window.c"
}


static void boxes_app_window_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesAppWindow* self;
#line 14 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) base;
#line 14 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (boxes_app_window_real_get_previous_ui_state (base) != value) {
#line 2862 "app-window.c"
		BoxesUIState _tmp0_;
#line 14 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = value;
#line 14 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self->priv->_previous_ui_state = _tmp0_;
#line 14 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_app_window_properties[BOXES_APP_WINDOW_PREVIOUS_UI_STATE_PROPERTY]);
#line 2870 "app-window.c"
	}
}


static BoxesUIState boxes_app_window_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesAppWindow* self;
	BoxesUIState _tmp0_;
#line 15 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) base;
#line 15 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_ui_state;
#line 15 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 15 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2887 "app-window.c"
}


static void boxes_app_window_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesAppWindow* self;
#line 15 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self = (BoxesAppWindow*) base;
#line 15 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (boxes_app_window_real_get_ui_state (base) != value) {
#line 2897 "app-window.c"
		BoxesUIState _tmp0_;
#line 15 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = value;
#line 15 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self->priv->_ui_state = _tmp0_;
#line 15 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_app_window_properties[BOXES_APP_WINDOW_UI_STATE_PROPERTY]);
#line 2905 "app-window.c"
	}
}


BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self) {
	BoxesCollectionItem* result;
	BoxesCollectionItem* _tmp0_;
#line 20 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 21 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_current_item;
#line 21 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 21 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 2921 "app-window.c"
}


static void _boxes_app_window_on_machine_state_notify_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 36 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_on_machine_state_notify ((BoxesAppWindow*) self);
#line 2928 "app-window.c"
}


static void _boxes_app_window_on_machine_deleted_notify_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 37 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_on_machine_deleted_notify ((BoxesAppWindow*) self);
#line 2935 "app-window.c"
}


void boxes_app_window_set_current_item (BoxesAppWindow* self, BoxesCollectionItem* value) {
	BoxesCollectionItem* _tmp0_;
	BoxesCollectionItem* _tmp5_;
	BoxesCollectionItem* _tmp6_;
	BoxesCollectionItem* _tmp7_;
#line 24 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 25 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_current_item;
#line 25 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp0_ != NULL) {
#line 2950 "app-window.c"
		BoxesCollectionItem* _tmp1_;
		gulong _tmp2_;
		BoxesCollectionItem* _tmp3_;
		gulong _tmp4_;
#line 26 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp1_ = self->priv->_current_item;
#line 26 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp2_ = self->priv->machine_state_notify_id;
#line 26 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 27 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp3_ = self->priv->_current_item;
#line 27 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp4_ = self->priv->machine_deleted_notify_id;
#line 27 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 28 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self->priv->machine_state_notify_id = (gulong) 0;
#line 29 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self->priv->machine_deleted_notify_id = (gulong) 0;
#line 2971 "app-window.c"
	}
#line 32 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp5_ = value;
#line 32 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 32 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->_current_item);
#line 32 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->_current_item = _tmp6_;
#line 33 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp7_ = self->priv->_current_item;
#line 33 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp7_ != NULL) {
#line 2985 "app-window.c"
		BoxesMachine* machine = NULL;
		BoxesCollectionItem* _tmp8_;
		BoxesMachine* _tmp9_;
		BoxesMachine* _tmp10_;
		gulong _tmp11_;
		BoxesMachine* _tmp12_;
		gulong _tmp13_;
#line 34 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp8_ = self->priv->_current_item;
#line 34 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp8_) : NULL);
#line 34 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		machine = _tmp9_;
#line 36 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp10_ = machine;
#line 36 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp11_ = g_signal_connect_object ((GObject*) _tmp10_, "notify::state", (GCallback) _boxes_app_window_on_machine_state_notify_g_object_notify, self, 0);
#line 36 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self->priv->machine_state_notify_id = _tmp11_;
#line 37 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp12_ = machine;
#line 37 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp13_ = g_signal_connect_object ((GObject*) _tmp12_, "notify::deleted", (GCallback) _boxes_app_window_on_machine_deleted_notify_g_object_notify, self, 0);
#line 37 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self->priv->machine_deleted_notify_id = _tmp13_;
#line 33 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_g_object_unref0 (machine);
#line 3013 "app-window.c"
	}
#line 24 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_app_window_properties[BOXES_APP_WINDOW_CURRENT_ITEM_PROPERTY]);
#line 3017 "app-window.c"
}


gboolean boxes_app_window_get_fullscreened (BoxesAppWindow* self) {
	gboolean result;
	GdkWindow* _tmp0_;
	GdkWindowState _tmp1_;
#line 50 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 50 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = gtk_widget_get_window ((GtkWidget*) self);
#line 50 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = gdk_window_get_state (_tmp0_);
#line 50 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = (_tmp1_ & GDK_WINDOW_STATE_FULLSCREEN) == GDK_WINDOW_STATE_FULLSCREEN;
#line 50 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 3035 "app-window.c"
}


void boxes_app_window_set_fullscreened (BoxesAppWindow* self, gboolean value) {
	gboolean _tmp0_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 52 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = value;
#line 52 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (_tmp0_) {
#line 53 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		gtk_window_fullscreen ((GtkWindow*) self);
#line 3049 "app-window.c"
	} else {
#line 55 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		gtk_window_unfullscreen ((GtkWindow*) self);
#line 3053 "app-window.c"
	}
}


static gboolean boxes_app_window_get_maximized (BoxesAppWindow* self) {
	gboolean result;
	GdkWindow* _tmp0_;
	GdkWindowState _tmp1_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 58 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = gtk_widget_get_window ((GtkWidget*) self);
#line 58 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = gdk_window_get_state (_tmp0_);
#line 58 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = (_tmp1_ & GDK_WINDOW_STATE_MAXIMIZED) == GDK_WINDOW_STATE_MAXIMIZED;
#line 58 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 3072 "app-window.c"
}


gboolean boxes_app_window_get_selection_mode (BoxesAppWindow* self) {
	gboolean result;
	gboolean _tmp0_;
#line 61 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 61 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_selection_mode;
#line 61 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 61 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 3087 "app-window.c"
}


void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value) {
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
	gboolean _tmp2_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 63 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 63 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 63 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (_tmp1_ == BOXES_UI_STATE_COLLECTION);
#line 65 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp2_ = value;
#line 65 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->_selection_mode = _tmp2_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_notify_by_pspec ((GObject *) self, boxes_app_window_properties[BOXES_APP_WINDOW_SELECTION_MODE_PROPERTY]);
#line 3109 "app-window.c"
}


BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self) {
	BoxesNotificationbar* result;
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
#line 70 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 71 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 71 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp1_ = _tmp0_;
#line 71 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	switch (_tmp1_) {
#line 71 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_WIZARD:
#line 3127 "app-window.c"
		{
			BoxesWizardWindow* _tmp2_;
			BoxesNotificationbar* _tmp3_;
#line 73 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp2_ = self->wizard_window;
#line 73 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp3_ = _tmp2_->notificationbar;
#line 73 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			result = _tmp3_;
#line 73 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			return result;
#line 3139 "app-window.c"
		}
#line 71 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 3143 "app-window.c"
		{
			BoxesPropertiesWindow* _tmp4_;
			BoxesNotificationbar* _tmp5_;
#line 75 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp4_ = self->props_window;
#line 75 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp5_ = _tmp4_->notificationbar;
#line 75 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			result = _tmp5_;
#line 75 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			return result;
#line 3155 "app-window.c"
		}
		default:
		{
			BoxesNotificationbar* _tmp6_;
#line 77 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp6_ = self->priv->_notificationbar;
#line 77 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			result = _tmp6_;
#line 77 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			return result;
#line 3166 "app-window.c"
		}
	}
}


BoxesAppWindowViewType boxes_app_window_get_view_type (BoxesAppWindow* self) {
	BoxesAppWindowViewType result;
	BoxesAppWindowViewType _tmp0_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_view_type;
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	result = _tmp0_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	return result;
#line 3183 "app-window.c"
}


void boxes_app_window_set_view_type (BoxesAppWindow* self, BoxesAppWindowViewType value) {
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_if_fail (self != NULL);
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	if (boxes_app_window_get_view_type (self) != value) {
#line 3192 "app-window.c"
		BoxesAppWindowViewType _tmp0_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		_tmp0_ = value;
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		self->priv->_view_type = _tmp0_;
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_app_window_properties[BOXES_APP_WINDOW_VIEW_TYPE_PROPERTY]);
#line 3200 "app-window.c"
	}
}


BoxesICollectionView* boxes_app_window_get_view (BoxesAppWindow* self) {
	BoxesICollectionView* result;
	BoxesAppWindowViewType _tmp0_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 106 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_tmp0_ = self->priv->_view_type;
#line 106 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	switch (_tmp0_) {
#line 3214 "app-window.c"
		default:
#line 106 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW_TYPE_ICON:
#line 3218 "app-window.c"
		{
			BoxesIconView* _tmp1_;
#line 109 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp1_ = self->priv->icon_view;
#line 109 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			result = (BoxesICollectionView*) _tmp1_;
#line 109 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			return result;
#line 3227 "app-window.c"
		}
#line 106 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW_TYPE_LIST:
#line 3231 "app-window.c"
		{
			BoxesListView* _tmp2_;
#line 111 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			_tmp2_ = self->priv->list_view;
#line 111 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			result = (BoxesICollectionView*) _tmp2_;
#line 111 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
			return result;
#line 3240 "app-window.c"
		}
	}
}


static void boxes_app_window_class_init (BoxesAppWindowClass * klass) {
	gint BoxesAppWindow_private_offset;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_type_class_add_private (klass, sizeof (BoxesAppWindowPrivate));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_app_window_get_property;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_app_window_set_property;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_app_window_finalize;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_PREVIOUS_UI_STATE_PROPERTY, boxes_app_window_properties[BOXES_APP_WINDOW_PREVIOUS_UI_STATE_PROPERTY] = g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_UI_STATE_PROPERTY, boxes_app_window_properties[BOXES_APP_WINDOW_UI_STATE_PROPERTY] = g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_CURRENT_ITEM_PROPERTY, boxes_app_window_properties[BOXES_APP_WINDOW_CURRENT_ITEM_PROPERTY] = g_param_spec_object ("current-item", "current-item", "current-item", BOXES_TYPE_COLLECTION_ITEM, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_FULLSCREENED_PROPERTY, boxes_app_window_properties[BOXES_APP_WINDOW_FULLSCREENED_PROPERTY] = g_param_spec_boolean ("fullscreened", "fullscreened", "fullscreened", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_SELECTION_MODE_PROPERTY, boxes_app_window_properties[BOXES_APP_WINDOW_SELECTION_MODE_PROPERTY] = g_param_spec_boolean ("selection-mode", "selection-mode", "selection-mode", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_NOTIFICATIONBAR_PROPERTY, boxes_app_window_properties[BOXES_APP_WINDOW_NOTIFICATIONBAR_PROPERTY] = g_param_spec_object ("notificationbar", "notificationbar", "notificationbar", BOXES_TYPE_NOTIFICATIONBAR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_VIEW_TYPE_PROPERTY, boxes_app_window_properties[BOXES_APP_WINDOW_VIEW_TYPE_PROPERTY] = g_param_spec_enum ("view-type", "view-type", "view-type", BOXES_APP_WINDOW_TYPE_VIEW_TYPE, BOXES_APP_WINDOW_VIEW_TYPE_ICON, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_WINDOW_VIEW_PROPERTY, boxes_app_window_properties[BOXES_APP_WINDOW_VIEW_PROPERTY] = g_param_spec_object ("view", "view", "view", BOXES_TYPE_ICOLLECTION_VIEW, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	BoxesAppWindow_private_offset = g_type_class_get_instance_private_offset (klass);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/app-window.ui");
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_signals[BOXES_APP_WINDOW_ITEM_SELECTED_SIGNAL] = g_signal_new ("item-selected", BOXES_TYPE_APP_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, BOXES_TYPE_COLLECTION_ITEM);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "searchbar", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, searchbar));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "topbar", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, topbar));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "selectionbar", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, selectionbar));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "display_page", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, display_page));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "empty_boxes", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, empty_boxes));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "below_bin", FALSE, G_STRUCT_OFFSET (BoxesAppWindow, below_bin));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "icon_view", FALSE, BoxesAppWindow_private_offset + G_STRUCT_OFFSET (BoxesAppWindowPrivate, icon_view));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "list_view", FALSE, BoxesAppWindow_private_offset + G_STRUCT_OFFSET (BoxesAppWindowPrivate, list_view));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "_notificationbar", FALSE, BoxesAppWindow_private_offset + G_STRUCT_OFFSET (BoxesAppWindowPrivate, _notificationbar));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_key_pressed", G_CALLBACK(_boxes_app_window_on_key_pressed_gtk_widget_key_press_event));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_configure_event", G_CALLBACK(_boxes_app_window_on_configure_event_gtk_widget_configure_event));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_window_state_event", G_CALLBACK(_boxes_app_window_on_window_state_event_gtk_widget_window_state_event));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_delete_event", G_CALLBACK(_boxes_app_window_on_delete_event_gtk_widget_delete_event));
#line 3306 "app-window.c"
}


static void boxes_app_window_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	boxes_app_window_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	iface->get_previous_ui_state = boxes_app_window_real_get_previous_ui_state;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	iface->set_previous_ui_state = boxes_app_window_real_set_previous_ui_state;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	iface->get_ui_state = boxes_app_window_real_get_ui_state;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	iface->set_ui_state = boxes_app_window_real_set_ui_state;
#line 3321 "app-window.c"
}


static void boxes_app_window_instance_init (BoxesAppWindow * self) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv = BOXES_APP_WINDOW_GET_PRIVATE (self);
#line 102 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->_view_type = BOXES_APP_WINDOW_VIEW_TYPE_ICON;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_SEARCHBAR);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_TOPBAR);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_SELECTIONBAR);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_DISPLAY_PAGE);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_EMPTY_BOXES);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_ICON_VIEW);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_LIST_VIEW);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	g_type_ensure (BOXES_TYPE_NOTIFICATIONBAR);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 3348 "app-window.c"
}


static void boxes_app_window_finalize (GObject * obj) {
	BoxesAppWindow * self;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_APP_WINDOW, BoxesAppWindow);
#line 18 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->_current_item);
#line 43 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->status_bind);
#line 82 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->wizard_window);
#line 83 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->props_window);
#line 86 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->searchbar);
#line 88 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->topbar);
#line 90 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->selectionbar);
#line 92 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->display_page);
#line 94 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->empty_boxes);
#line 96 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->below_bin);
#line 98 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->icon_view);
#line 100 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->list_view);
#line 116 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	self->priv->views = (_vala_array_free (self->priv->views, self->priv->views_length1, (GDestroyNotify) g_object_unref), NULL);
#line 118 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->settings);
#line 121 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->_notificationbar);
#line 126 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	_g_object_unref0 (self->priv->group);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	G_OBJECT_CLASS (boxes_app_window_parent_class)->finalize (obj);
#line 3390 "app-window.c"
}


GType boxes_app_window_get_type (void) {
	static volatile gsize boxes_app_window_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_app_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesAppWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_app_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesAppWindow), 0, (GInstanceInitFunc) boxes_app_window_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_app_window_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_app_window_type_id;
		boxes_app_window_type_id = g_type_register_static (gtk_application_window_get_type (), "BoxesAppWindow", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_app_window_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_app_window_type_id__volatile, boxes_app_window_type_id);
	}
	return boxes_app_window_type_id__volatile;
}


static void _vala_boxes_app_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesAppWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP_WINDOW, BoxesAppWindow);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	switch (property_id) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_PREVIOUS_UI_STATE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_UI_STATE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_CURRENT_ITEM_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_value_set_object (value, boxes_app_window_get_current_item (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_FULLSCREENED_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_value_set_boolean (value, boxes_app_window_get_fullscreened (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_SELECTION_MODE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_value_set_boolean (value, boxes_app_window_get_selection_mode (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_NOTIFICATIONBAR_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_value_set_object (value, boxes_app_window_get_notificationbar (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW_TYPE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_value_set_enum (value, boxes_app_window_get_view_type (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		g_value_set_object (value, boxes_app_window_get_view (self));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 3461 "app-window.c"
		default:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 3467 "app-window.c"
	}
}


static void _vala_boxes_app_window_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesAppWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP_WINDOW, BoxesAppWindow);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
	switch (property_id) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_PREVIOUS_UI_STATE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_UI_STATE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_CURRENT_ITEM_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_current_item (self, g_value_get_object (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_FULLSCREENED_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_fullscreened (self, g_value_get_boolean (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_SELECTION_MODE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_selection_mode (self, g_value_get_boolean (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		case BOXES_APP_WINDOW_VIEW_TYPE_PROPERTY:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		boxes_app_window_set_view_type (self, g_value_get_enum (value));
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 3513 "app-window.c"
		default:
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/fborges/checkout/gnome-boxes/src/app-window.vala"
		break;
#line 3519 "app-window.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



